@@ -12,18 +12,19 @@ works as expected:
 
 from __future__ import absolute_import, print_function, unicode_literals
 
-import unittest
 import copy
 
 from future import utils
+from future.tests.base import unittest
+
 
 original_locals = set(copy.copy(locals()))
 original_globals = set(copy.copy(globals()))
-new_names = {'original_locals', 'original_globals', 'new_names'}
+new_names = set(['original_locals', 'original_globals', 'new_names'])
 from future.builtins import *
 new_locals = set(copy.copy(locals())) - new_names - original_locals
 new_globals = set(copy.copy(globals())) - new_names - original_globals - \
-              {'new_locals'}
+              set(['new_locals'])
 
 
 class TestImportStar(unittest.TestCase):
