@@ -68,6 +68,7 @@ from __future__ import unicode_literals
 
 import types
 import sys
+import numbers
 
 PY3 = sys.version_info[0] == 3
 PY2 = sys.version_info[0] == 2
@@ -376,6 +377,62 @@ def is_new_style(cls):
 # ``from future.builtins import *``.
 native_str = str
 
+def istext(obj):
+    return isinstance(obj, type(u''))
+
+
+def isbytes(obj):
+    return isinstance(obj, type(b''))
+
+
+def isint(obj):
+    """
+    Instead of using this function, you can use the following idiom:
+        isinstance(obj, numbers.Integral)
+    """
+    return isinstance(obj, numbers.Integral)
+
+
+def native(obj):
+    """
+    On Py3, this is a no-op: native(obj) -> obj
+
+    On Py2, returns the corresponding native Py2 types that are
+    superclasses for backported objects from Py3:
+    
+    >>> native(str(u'ABC'))
+    u'ABC'
+    >>> type(native(str(u'ABC')))
+    unicode
+
+    >>> native(bytes(b'ABC'))
+    b'ABC'
+    >>> type(native(bytes(b'ABC')))
+    bytes
+
+    >>> native(int(10**20))
+    100000000000000000000L
+    >>> type(native(int(10**20)))
+    long
+
+    Existing native types on Py2 will be returned unchanged:
+
+    >>> type(native(u'ABC'))
+    unicode
+    """
+    if hasattr(obj, '__native__'):
+        return obj.__native__()
+    else:
+        return obj
+
+
+def old_div(a, b):
+    """
+    Equivalent to Python 2's ``a / b`` before ``from __future__ import
+    division``.
+    """
+    return a // b if (isint(a) and isint(b)) else a / b
+
 
 __all__ = ['PY3', 'PY2', 'PYPY', 'python_2_unicode_compatible',
            'with_metaclass', 'bchr', 'bstr', 'bord',
